Index: chrome/browser/tab_contents/tab_contents.h |
diff --git a/chrome/browser/tab_contents/tab_contents.h b/chrome/browser/tab_contents/tab_contents.h |
index 3ae7941ed04793e0b28b4b0e28216120695f1066..ddf8ae4a6c8d666fa6f0986eee4bdcf6be3b1c74 100644 |
--- a/chrome/browser/tab_contents/tab_contents.h |
+++ b/chrome/browser/tab_contents/tab_contents.h |
@@ -734,8 +734,8 @@ class TabContents : public PageNavigator, |
int GetZoomPercent(bool* enable_increment, bool* enable_decrement); |
// Shows a fade effect over this tab contents. Repeated calls will be ignored |
- // until the fade is canceled. |
- void FadeForInstant(); |
+ // until the fade is canceled. If |animate| is true the fade should animate. |
+ void FadeForInstant(bool animate); |
// Immediately removes the fade. |
void CancelInstantFade(); |